@@ -33,6 +33,7 @@
 #  define KNEWSTUFFCORE_DECL_DEPRECATED_NO_EXPORT KNEWSTUFFCORE_NO_EXPORT KNEWSTUFFCORE_DECL_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KNEWSTUFFCORE_NO_DEPRECATED
 #    define KNEWSTUFFCORE_NO_DEPRECATED
@@ -84,7 +85,7 @@
 #define KNEWSTUFFCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED
-#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
 #endif
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +95,7 @@
 #  ifdef KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x57400
 #  endif
 #endif
 
